@@ -14,7 +14,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package Sys::OsRelease;
-$Sys::OsRelease::VERSION = '0.1.0';
+$Sys::OsRelease::VERSION = '0.1.1';
 use Config;
 use Carp qw(carp croak);
 
@@ -193,7 +193,7 @@ sub platform
 
             # check ID_LIKE for more common names which should be used instead of ID
             foreach my $like (split /\s+/x, $self->id_like) {
-                if ($common_id{$like} // 0) {
+                if (exists $common_id{$like}) {
                     $self->config("platform", $like);
                     last;
                 }
@@ -239,7 +239,7 @@ sub get
 {
     my ($class_or_obj, $key) = @_;
     my $self = class_or_obj($class_or_obj);
-    return $self->{fold_case($key)} // undef;
+    return $self->{fold_case($key)};
 }
 
 # attribute existence checker
@@ -301,7 +301,7 @@ sub _gen_accessor
     # generate accessor as read-only or undef depending whether it exists in the running system
     if (exists $self->{$name}) {
         # generate read-only accessor for attribute which was found in os-release
-        $self->{_config}{accessor}{$name} = sub { return $self->{$name} // undef };
+        $self->{_config}{accessor}{$name} = sub { return $self->{$name} };
     } else {
         # generate undef accessor for standard attribute which was not found in os-release
         $self->{_config}{accessor}{$name} = sub { return; };
@@ -362,7 +362,7 @@ Sys::OsRelease - read operating system details from standard /etc/os-release fil
 
 =head1 VERSION
 
-version 0.1.0
+version 0.1.1
 
 =head1 SYNOPSIS
 
